@@ -76,8 +76,7 @@ sjp.fa <- function(data,
                     wrap.title = 50,
                     wrap.labels = 30,
                     show.values = TRUE,
-                    show.cronb = TRUE,
-                    prnt.plot = TRUE) {
+                    show.cronb = TRUE) {
   # --------------------------------------------------------
   # check arguments
   # --------------------------------------------------------
@@ -242,9 +241,9 @@ sjp.fa <- function(data,
   # start with base plot object here
   # --------------------------------------------------------
   if (type == "bar") {
-    heatmap <- ggplot(df, aes(x = rev(factor(ypos)), y = abs(value), fill = value))
+    heatmap <- ggplot(df, aes(x = rev(factor(.data$ypos)), y = abs(.data$value), fill = .data$value))
   } else {
-    heatmap <- ggplot(data = df, aes(x = xpos, y = ypos, fill = value))
+    heatmap <- ggplot(data = df, aes(x = .data$xpos, y = .data$ypos, fill = .data$value))
   }
   # --------------------------------------------------------
   # determine the geom type, either points when "type" is "circles"
@@ -300,7 +299,7 @@ sjp.fa <- function(data,
   # --------------------------------------------------------
   # print plot
   # --------------------------------------------------------
-  if (prnt.plot) graphics::plot(heatmap)
+  graphics::plot(heatmap)
   # --------------------------------------------------------
   # if we have a data frame, all factors which do not clearly
   # load on a specific dimension (see patameter "fctr.load.tlrn")
