@@ -1,6 +1,4 @@
-# bind global variables
-utils::globalVariables(c("val", "frq", "grp", "label.pos", "upper.ci", "lower.ci", "..density.."))
-
+utils::globalVariables("density")
 
 #' @title Plot frequencies of variables
 #' @name sjp.frq
@@ -46,13 +44,18 @@ utils::globalVariables(c("val", "frq", "grp", "label.pos", "upper.ci", "lower.ci
 #' @param xlim Numeric vector of length two, defining lower and upper axis limits
 #'          of the x scale. By default, this argument is set to \code{NULL}, i.e. the
 #'          x-axis fits to the required range of the data.
+#' @param axis.title Character vector of length one or two (depending on
+#'          the plot function and type), used as title(s) for the x and y axis.
+#'          If not specified, a default labelling  is chosen.
+#'          \strong{Note:} Some plot types do not support this argument. In such
+#'          cases, use the return value and add axis titles manually with
+#'          \code{\link[ggplot2]{labs}}, e.g.: \code{$plot.list[[1]] + labs(x = ...)}
 #'
 #' @inheritParams sjp.grpfrq
 #' @inheritParams sjp.lm
 #' @inheritParams sjp.glmer
 #'
-#' @return (Insisibily) returns the ggplot-object with the complete plot (\code{plot}) as well as the data frame that
-#'           was used for setting up the ggplot-object (\code{data}).
+#' @return A ggplot-object.
 #'
 #' @examples
 #' library(sjlabelled)
@@ -95,6 +98,7 @@ utils::globalVariables(c("val", "frq", "grp", "label.pos", "upper.ci", "lower.ci
 #' @importFrom sjmisc group_labels group_var to_value
 #' @importFrom sjlabelled set_labels
 #' @importFrom stats na.omit sd weighted.mean dnorm
+#' @importFrom rlang .data
 #' @export
 sjp.frq <- function(var.cnt,
                     title = "",
@@ -134,8 +138,7 @@ sjp.frq <- function(var.cnt,
                     coord.flip = FALSE,
                     vjust = "bottom",
                     hjust = "center",
-                    y.offset = NULL,
-                    prnt.plot = TRUE) {
+                    y.offset = NULL) {
 
   # get variable name, used as default label if variable
   # has no label attributes
@@ -173,8 +176,8 @@ sjp.frq <- function(var.cnt,
     axis.labels <- sjlabelled::get_labels(
       var.cnt,
       attr.only = F,
-      include.values = NULL,
-      include.non.labelled = T
+      values = NULL,
+      non.labelled = T
     )
   }
 
@@ -194,7 +197,7 @@ sjp.frq <- function(var.cnt,
 
   # default grid-expansion
   if (isTRUE(expand.grid) || (missing(expand.grid) && type == "histogram")) {
-    expand.grid <- ggplot2::waiver()
+    expand.grid <- waiver()
   } else {
     expand.grid <- c(0, 0)
   }
@@ -370,7 +373,7 @@ sjp.frq <- function(var.cnt,
             label = sprintf("%i (%.01f%%)", mydat$frq, mydat$valid.prc),
             hjust = hjust,
             vjust = vjust,
-            aes(y = label.pos + y_offset)
+            aes(y = .data$label.pos + y_offset)
           )
       } else {
         ggvaluelabels <-
@@ -378,7 +381,7 @@ sjp.frq <- function(var.cnt,
             label = sprintf("%i\n(%.01f%%)", mydat$frq, mydat$valid.prc),
             hjust = hjust,
             vjust = vjust,
-            aes(y = label.pos + y_offset)
+            aes(y = .data$label.pos + y_offset)
           )
       }
     } else if (show.n) {
@@ -387,7 +390,7 @@ sjp.frq <- function(var.cnt,
         label = sprintf("%i", mydat$frq),
         hjust = hjust,
         vjust = vjust,
-        aes(y = label.pos + y_offset)
+        aes(y = .data$label.pos + y_offset)
       )
     } else if (show.prc) {
       # here we have counts, without percentages
@@ -396,22 +399,22 @@ sjp.frq <- function(var.cnt,
           label = sprintf("%.01f%%", mydat$valid.prc),
           hjust = hjust,
           vjust = vjust,
-          aes(y = label.pos + y_offset)
+          aes(y = .data$label.pos + y_offset)
         )
     } else {
       # no labels
-      ggvaluelabels <-  geom_text(aes(y = frq), label = "")
+      ggvaluelabels <-  geom_text(aes(y = .data$frq), label = "")
     }
   } else {
     # no labels
-    ggvaluelabels <-  geom_text(aes(y = frq), label = "")
+    ggvaluelabels <-  geom_text(aes(y = .data$frq), label = "")
   }
 
   # Set up grid breaks
   maxx <- max(mydat$val) + 1
   if (is.null(grid.breaks)) {
-    gridbreaks <- ggplot2::waiver()
-    histgridbreaks <- ggplot2::waiver()
+    gridbreaks <- waiver()
+    histgridbreaks <- waiver()
   } else {
     gridbreaks <- c(seq(lower_lim, upper_lim, by = grid.breaks))
     histgridbreaks <- c(seq(lower_lim, maxx, by = grid.breaks))
@@ -447,7 +450,7 @@ sjp.frq <- function(var.cnt,
     # mydat is a data frame that only contains one variable (var).
     # Must be declared as factor, so the bars are central aligned to
     # each x-axis-break.
-    baseplot <- ggplot(mydat, aes(x = factor(val), y = frq)) +
+    baseplot <- ggplot(mydat, aes(x = factor(.data$val), y = .data$frq)) +
       geob +
       yscale +
       # remove guide / legend
@@ -507,10 +510,10 @@ sjp.frq <- function(var.cnt,
   # Start density plot here -----
   } else if (type == "density") {
     # First, plot histogram with density curve
-    baseplot <- ggplot(hist.dat, aes(x = xv)) +
-      geom_histogram(aes(y = ..density..), binwidth = geom.size, fill = geom.colors) +
+    baseplot <- ggplot(hist.dat, aes(x = .data$xv)) +
+      geom_histogram(aes(y = stat(density)), binwidth = geom.size, fill = geom.colors) +
       # transparent density curve above bars
-      geom_density(aes(y = ..density..), fill = "cornsilk", alpha = 0.3) +
+      geom_density(aes(y = stat(density)), fill = "cornsilk", alpha = 0.3) +
       # remove margins from left and right diagram side
       scale_x_continuous(expand = expand.grid, breaks = histgridbreaks, limits = xlim)
 
@@ -537,9 +540,9 @@ sjp.frq <- function(var.cnt,
       # original data needed for normal curve
       baseplot <- ggplot(mydat) +
         # second data frame mapped to the histogram geom
-        geom_histogram(data = hist.dat, aes(x = xv), binwidth = geom.size, fill = geom.colors)
+        geom_histogram(data = hist.dat, aes(x = .data$xv), binwidth = geom.size, fill = geom.colors)
     } else {
-      baseplot <- ggplot(mydat, aes(x = val, y = frq)) +
+      baseplot <- ggplot(mydat, aes(x = .data$val, y = .data$frq)) +
         geom_area(alpha = 0.3) +
         geom_line(size = geom.size, colour = geom.colors) +
         ggvaluelabels
@@ -619,8 +622,5 @@ sjp.frq <- function(var.cnt,
   baseplot <- baseplot + labs(title = title, x = axis.title, y = NULL)
 
   # Check whether ggplot object should be returned or plotted
-  if (prnt.plot) graphics::plot(baseplot)
-
-  # return results
-  invisible(structure(class = "sjpfrq", list(plot = baseplot, data = mydat)))
+  baseplot
 }
