@@ -3,7 +3,7 @@ tidy_model <- function(model, ci.lvl, tf, type, bpe, se, facets, show.zeroinf, p
 
   # get robust standard errors, if requestes, and replace former s.e.
   if (!is.null(se) && !is.logical(se)) {
-    std.err <- sjstats::robust(model, se)
+    std.err <- sjstats::robust(model, vcov.type = se)
     dat[["std.error"]] <- std.err[["std.error"]]
   }
 
@@ -44,7 +44,6 @@ get_tidy_data <- function(model, ci.lvl, tf, type, bpe, facets, show.zeroinf, p.
 
 
 #' @importFrom broom tidy
-#' @importFrom tibble has_name
 #' @importFrom sjstats p_value
 #' @importFrom stats coef qnorm
 #' @importFrom dplyr mutate
@@ -64,7 +63,6 @@ tidy_generic <- function(model, ci.lvl, facets, p.val) {
     # get estimates, as data frame
     dat <- broom::tidy(model, conf.int = FALSE, exponentiate = FALSE)
 
-
     # add conf. int.
 
     dat <- dat %>%
@@ -84,7 +82,13 @@ tidy_generic <- function(model, ci.lvl, facets, p.val) {
   } else {
 
     # tidy the model
-    dat <- broom::tidy(model, conf.int = TRUE, conf.level = ci.lvl, effects = "fixed")
+
+    if (inherits(model, "lmerModLmerTest")) {
+      dat <- tidy_lmerModLmerTest(model, ci.lvl)
+    } else {
+      dat <- broom::tidy(model, conf.int = TRUE, conf.level = ci.lvl, effects = "fixed")
+    }
+
 
     if (is_merMod(model) && !is.null(p.val) && p.val == "kr") {
       pv <- tryCatch(
@@ -107,7 +111,7 @@ tidy_generic <- function(model, ci.lvl, facets, p.val) {
     } else {
 
       # see if we have p-values. if not, add them
-      if (!tibble::has_name(dat, "p.value"))
+      if (!obj_has_name(dat, "p.value"))
         dat$p.value <- tryCatch(
           sjstats::p_value(model, p.kr = FALSE)[["p.value"]],
           error = function(x) { NA }
@@ -119,8 +123,24 @@ tidy_generic <- function(model, ci.lvl, facets, p.val) {
 }
 
 
+#' @importFrom stats qnorm
+#' @importFrom dplyr select
+tidy_lmerModLmerTest <- function(model, ci.lvl) {
+  dat <- summary(model)$coef %>%
+    as.data.frame() %>%
+    rownames_as_column(var = "term") %>%
+    dplyr::select(1, 2, 3, 5)
+
+  colnames(dat) <- c("term", "estimate", "std.error", "statistic")
+
+  dat$conf.low <- dat$estimate - stats::qnorm(ci.lvl) * dat$std.error
+  dat$conf.high <- dat$estimate + stats::qnorm(ci.lvl) * dat$std.error
+
+  dat
+}
+
+
 #' @importFrom stats coef vcov qnorm pnorm
-#' @importFrom tibble tibble
 tidy_svynb_model <- function(model, ci.lvl) {
   if (!isNamespaceLoaded("survey"))
     requireNamespace("survey", quietly = TRUE)
@@ -140,7 +160,7 @@ tidy_svynb_model <- function(model, ci.lvl) {
   se <- sqrt(diag(stats::vcov(model, stderr = "robust")))
 
 
-  tibble::tibble(
+  data_frame(
     term = gsub("\\beta\\.", "", names(est), fixed = FALSE),
     estimate = est,
     std.error = se,
@@ -152,14 +172,13 @@ tidy_svynb_model <- function(model, ci.lvl) {
 
 
 #' @importFrom broom tidy
-#' @importFrom tibble has_name
 #' @importFrom sjstats p_value
 tidy_cox_model <- function(model, ci.lvl) {
   # tidy the model
   dat <- broom::tidy(model, conf.int = ci.lvl)
 
   # see if we have p-values. if not, add them
-  if (!tibble::has_name(dat, "p.value"))
+  if (!obj_has_name(dat, "p.value"))
     dat$p.value <- sjstats::p_value(model)[["p.value"]]
 
   dat
@@ -172,10 +191,8 @@ tidy_cox_model <- function(model, ci.lvl) {
 #' @importFrom sjstats hdi typical_value model_family
 #' @importFrom sjmisc var_rename add_columns is_empty
 #' @importFrom dplyr select filter slice inner_join n_distinct
-#' @importFrom tibble add_column tibble
 #' @importFrom purrr map_dbl
 #' @importFrom rlang .data
-#' @importFrom tidyselect starts_with ends_with
 tidy_stan_model <- function(model, ci.lvl, tf, type, bpe, show.zeroinf, facets, ...) {
 
   # set defaults
@@ -183,6 +200,8 @@ tidy_stan_model <- function(model, ci.lvl, tf, type, bpe, show.zeroinf, facets,
   p.inner <- .5
   p.outer <- ci.lvl
 
+  # get model information
+  modfam <- sjstats::model_family(model)
 
   # additional arguments for 'effects()'-function?
   add.args <- lapply(match.call(expand.dots = F)$`...`, function(x) x)
@@ -220,11 +239,11 @@ tidy_stan_model <- function(model, ci.lvl, tf, type, bpe, show.zeroinf, facets,
   mod.dat <- as.data.frame(model)
 
   if (inherits(model, "brmsfit")) {
-    re.sd <- tidyselect::starts_with("sd_", vars = colnames(mod.dat))
-    re.cor <- tidyselect::starts_with("cor_", vars = colnames(mod.dat))
-    lp <- tidyselect::starts_with("lp__", vars = colnames(mod.dat))
-    resp.cor <- tidyselect::starts_with("rescor__", vars = colnames(mod.dat))
-    priors <- tidyselect::starts_with("prior_", vars = colnames(mod.dat))
+    re.sd <- string_starts_with("sd_", x = colnames(mod.dat))
+    re.cor <- string_starts_with("cor_", x = colnames(mod.dat))
+    lp <- string_starts_with("lp__", x = colnames(mod.dat))
+    resp.cor <- string_starts_with("rescor__", x = colnames(mod.dat))
+    priors <- string_starts_with("prior_", x = colnames(mod.dat))
 
     brmsfit.removers <- unique(c(re.sd, re.cor, lp, resp.cor, priors))
 
@@ -232,7 +251,7 @@ tidy_stan_model <- function(model, ci.lvl, tf, type, bpe, show.zeroinf, facets,
       mod.dat <- dplyr::select(mod.dat, !! -brmsfit.removers)
 
     # also clean prepared data frame
-    resp.cor <- tidyselect::starts_with("rescor__", vars = dat$term)
+    resp.cor <- string_starts_with("rescor__", x = dat$term)
 
     if (!sjmisc::is_empty(resp.cor))
       dat <- dplyr::slice(dat, !! -resp.cor)
@@ -243,7 +262,7 @@ tidy_stan_model <- function(model, ci.lvl, tf, type, bpe, show.zeroinf, facets,
 
   est <- purrr::map_dbl(mod.dat, ~ sjstats::typical_value(.x, fun = bpe))
 
-  dat <- tibble::tibble(
+  dat <- data_frame(
     term = names(est),
     estimate = est,
     p.value = 0,
@@ -266,20 +285,20 @@ tidy_stan_model <- function(model, ci.lvl, tf, type, bpe, show.zeroinf, facets,
 
   # remove sd_c and cor_ row
 
-  re <- tidyselect::starts_with("sd_", vars = dat$term)
+  re <- string_starts_with("sd_", x = dat$term)
   if (!sjmisc::is_empty(re)) dat <- dplyr::slice(dat, !! -re)
 
-  re <- tidyselect::starts_with("cor_", vars = dat$term)
+  re <- string_starts_with("cor_", x = dat$term)
   if (!sjmisc::is_empty(re)) dat <- dplyr::slice(dat, !! -re)
 
 
   # check if we need to keep or remove random effects
 
-  re <- tidyselect::starts_with("b[", vars = dat$term)
-  re.s <- tidyselect::starts_with("Sigma[", vars = dat$term)
+  re <- string_starts_with("b[", x = dat$term)
+  re.s <- string_starts_with("Sigma[", x = dat$term)
   re.i <- intersect(
-    tidyselect::starts_with("r_", vars = dat$term),
-    tidyselect::ends_with(".", vars = dat$term)
+    string_starts_with("r_", x = dat$term),
+    string_ends_with(".", x = dat$term)
   )
 
   # and all random effect error terms
@@ -383,17 +402,33 @@ tidy_stan_model <- function(model, ci.lvl, tf, type, bpe, show.zeroinf, facets,
   }
 
 
+  # categorical model?
+
+  if (inherits(model, "brmsfit") && modfam$is_categorical) {
+
+    # terms of categorical models are prefixed with "mu"
+
+    if (length(string_starts_with("b_mu", x = dat$term)) == nrow(dat)) {
+      dat$term <- substr(dat$term, 5, max(nchar(dat$term)))
+      # create "response-level" variable
+      dat <- add_cols(dat, response.level = "", .before = 1)
+      dat$response.level <- gsub("(.*)\\_(.*)", "\\1", dat$term)
+      dat$term <- gsub("(.*)\\_(.*)", "\\2", dat$term)
+    }
+  }
+
+
   # multivariate-response model?
 
-  if (inherits(model, "brmsfit") && !is.null(stats::formula(model)$responses)) {
+  if (inherits(model, "brmsfit") && modfam$is_multivariate) {
 
     # get response variables
 
     responses <- stats::formula(model)$responses
 
     # also clean prepared data frame
-    resp.sigma1 <- tidyselect::starts_with("sigma_", vars = dat$term)
-    resp.sigma2 <- tidyselect::starts_with("b_sigma_", vars = dat$term)
+    resp.sigma1 <- string_starts_with("sigma_", x = dat$term)
+    resp.sigma2 <- string_starts_with("b_sigma_", x = dat$term)
 
     resp.sigma <- c(resp.sigma1, resp.sigma2)
 
@@ -403,13 +438,13 @@ tidy_stan_model <- function(model, ci.lvl, tf, type, bpe, show.zeroinf, facets,
 
     # create "response-level" variable
 
-    dat <- tibble::add_column(dat, response.level = "", .before = 1)
+    dat <- add_cols(dat, response.level = "", .before = 1)
 
     # copy name of response into new character variable
     # and remove response name from term name
 
     for (i in responses) {
-      m <- tidyselect::contains(i, vars = dat$term)
+      m <- string_contains(i, x = dat$term)
       dat$response.level[intersect(which(dat$response.level == ""), m)] <- i
       dat$term <- gsub(sprintf("b_%s_", i), "", dat$term, fixed = TRUE)
       dat$term <- gsub(sprintf("s_%s_", i), "", dat$term, fixed = TRUE)
@@ -428,13 +463,11 @@ tidy_stan_model <- function(model, ci.lvl, tf, type, bpe, show.zeroinf, facets,
 
   # do we have a zero-inflation model?
 
-  modfam <- sjstats::model_family(model)
-
   if (modfam$is_zeroinf || sjmisc::str_contains(dat$term, "b_zi_", ignore.case = T)) {
     dat$wrap.facet <- "Conditional Model"
 
     # zero-inflated part
-    zi <- tidyselect::starts_with("b_zi_", vars = dat$term)
+    zi <- string_starts_with("b_zi_", x = dat$term)
 
     # check if zero-inflated part should be shown or removed
     if (show.zeroinf) {
@@ -454,7 +487,7 @@ tidy_stan_model <- function(model, ci.lvl, tf, type, bpe, show.zeroinf, facets,
 
 
   # remove facet column if not necessary
-  if (!show.zeroinf && tibble::has_name(dat, "wrap.facet"))
+  if (!show.zeroinf && obj_has_name(dat, "wrap.facet"))
     dat <- dplyr::select(dat, -.data$wrap.facet)
 
   dat
@@ -462,7 +495,6 @@ tidy_stan_model <- function(model, ci.lvl, tf, type, bpe, show.zeroinf, facets,
 
 
 #' @importFrom broom tidy
-#' @importFrom tibble has_name
 #' @importFrom sjstats p_value
 #' @importFrom nlme intervals
 tidy_lme_model <- function(model, ci.lvl) {
@@ -476,7 +508,7 @@ tidy_lme_model <- function(model, ci.lvl) {
   dat$conf.high <- ci$upper
 
   # see if we have p-values. if not, add them
-  if (!tibble::has_name(dat, "p.value"))
+  if (!obj_has_name(dat, "p.value"))
     dat$p.value <- sjstats::p_value(model)[["p.value"]]
 
   dat
@@ -486,7 +518,6 @@ tidy_lme_model <- function(model, ci.lvl) {
 #' @importFrom sjmisc var_rename
 #' @importFrom nlme intervals
 #' @importFrom dplyr select
-#' @importFrom tibble rownames_to_column
 tidy_gls_model <- function(model, ci.lvl) {
   # get tidy summary. for lme, this excludes CI,
   # so we compute them separately
@@ -505,13 +536,12 @@ tidy_gls_model <- function(model, ci.lvl) {
     `t-value` = "statistic",
     `p-value` = "p.value"
   ) %>%
-    tibble::rownames_to_column("term")
+    rownames_as_column(var = "term")
 }
 
 
 #' @importFrom glmmTMB fixef
 #' @importFrom stats vcov qnorm pnorm
-#' @importFrom tibble tibble
 #' @importFrom sjmisc is_empty
 #' @importFrom dplyr bind_rows
 #' @importFrom rlang .data
@@ -528,33 +558,49 @@ tidy_glmmTMB_model <- function(model, ci.lvl, show.zeroinf) {
   # get fixed effects
 
   est <- glmmTMB::fixef(model)
-  vcovs <- stats::vcov(model)
+
+  # model may have error "system is computationally singular", then
+  # no vcov can be calculated
+
+  vcovs <- tryCatch(
+    {
+      stats::vcov(model)
+    },
+    error = function(x) { c(list(matrix(NA)), list(matrix(NA))) },
+    warning = function(x) { c(list(matrix(NA)), list(matrix(NA))) },
+    finally = function(x) { c(list(matrix(NA)), list(matrix(NA))) }
+  )
 
 
   # save conditional model
 
-  cond <- tibble::tibble(
+  se.cond <- sqrt(diag(vcovs[[1]]))
+
+  cond <- data_frame(
     term = names(est[[1]]),
     estimate = est[[1]],
-    std.error = sqrt(diag(vcovs[[1]])),
-    statistic = .data$estimate / .data$std.error,
-    conf.low = .data$estimate - stats::qnorm(ci) * .data$std.error,
-    conf.high = .data$estimate + stats::qnorm(ci) * .data$std.error,
-    p.value = 2 * stats::pnorm(abs(.data$estimate / .data$std.error), lower.tail = FALSE),
+    std.error = se.cond,
+    statistic = est[[1]] / se.cond,
+    conf.low = est[[1]] - stats::qnorm(ci) * se.cond,
+    conf.high = est[[1]] + stats::qnorm(ci) * se.cond,
+    p.value = 2 * stats::pnorm(abs(est[[1]] / se.cond), lower.tail = FALSE),
     wrap.facet = "Conditional Model"
   )
 
   # save zi model
 
   if (!sjmisc::is_empty(est[[2]]) && show.zeroinf) {
-    zi <- tibble::tibble(
+
+    se.zi <- sqrt(diag(vcovs[[2]]))
+
+    zi <- data_frame(
       term = names(est[[2]]),
       estimate = est[[2]],
-      std.error = sqrt(diag(vcovs[[2]])),
-      statistic = .data$estimate / .data$std.error,
-      conf.low = .data$estimate - stats::qnorm(ci) * .data$std.error,
-      conf.high = .data$estimate + stats::qnorm(ci) * .data$std.error,
-      p.value = 2 * stats::pnorm(abs(.data$estimate / .data$std.error), lower.tail = FALSE),
+      std.error = se.zi,
+      statistic = est[[2]] / se.zi,
+      conf.low = est[[2]] - stats::qnorm(ci) * se.zi,
+      conf.high = est[[2]] + stats::qnorm(ci) * se.zi,
+      p.value = 2 * stats::pnorm(abs(est[[2]] / se.zi), lower.tail = FALSE),
       wrap.facet = "Zero-Inflated Model"
     )
 
@@ -570,7 +616,6 @@ tidy_glmmTMB_model <- function(model, ci.lvl, show.zeroinf) {
 
 
 #' @importFrom stats qnorm
-#' @importFrom tibble rownames_to_column
 #' @importFrom sjmisc var_rename
 #' @importFrom dplyr mutate
 #' @importFrom purrr map2_df
@@ -593,7 +638,7 @@ tidy_hurdle_model <- function(model, ci.lvl) {
   purrr::map2_df(est, mn, function(x, y) {
     x %>%
       as.data.frame() %>%
-      tibble::rownames_to_column(var = "term") %>%
+      rownames_as_column(var = "term") %>%
       sjmisc::var_rename(
         Estimate = "estimate",
         `Std. Error` = "std.error",
@@ -610,7 +655,6 @@ tidy_hurdle_model <- function(model, ci.lvl) {
 
 
 #' @importFrom stats qnorm
-#' @importFrom tibble tibble
 #' @importFrom rlang .data
 tidy_logistf_model <- function(model, ci.lvl) {
 
@@ -628,20 +672,19 @@ tidy_logistf_model <- function(model, ci.lvl) {
   se <- sqrt(diag(model$var))
 
 
-  tibble::tibble(
+  data_frame(
     term = model$terms,
     estimate = est,
     std.error = se,
-    statistic = .data$estimate / .data$std.error,
-    conf.low = .data$estimate - stats::qnorm(ci) * .data$std.error,
-    conf.high = .data$estimate + stats::qnorm(ci) * .data$std.error,
+    statistic = est / se,
+    conf.low = est - stats::qnorm(ci) * se,
+    conf.high = est + stats::qnorm(ci) * se,
     p.value = model$prob
   )
 }
 
 
 #' @importFrom stats qnorm
-#' @importFrom tibble rownames_to_column
 #' @importFrom rlang .data
 #' @importFrom dplyr mutate
 tidy_clm_model <- function(model, ci.lvl) {
@@ -659,7 +702,7 @@ tidy_clm_model <- function(model, ci.lvl) {
   smry <- summary(model)
   est <- smry$coefficients %>%
     as.data.frame() %>%
-    tibble::rownames_to_column(var = "term")
+    rownames_as_column(var = "term")
 
   # proper column names
   colnames(est) <- c("term", "estimate", "std.error", "statistic", "p.value")
@@ -682,7 +725,6 @@ tidy_clm_model <- function(model, ci.lvl) {
 
 
 #' @importFrom stats qnorm pnorm
-#' @importFrom tibble rownames_to_column
 #' @importFrom rlang .data
 #' @importFrom dplyr mutate
 tidy_polr_model <- function(model, ci.lvl) {
@@ -700,7 +742,7 @@ tidy_polr_model <- function(model, ci.lvl) {
   smry <- summary(model)
   est <- smry$coefficients %>%
     as.data.frame() %>%
-    tibble::rownames_to_column(var = "term")
+    rownames_as_column(var = "term")
 
   # proper column names
   colnames(est) <- c("term", "estimate", "std.error", "statistic")
@@ -761,7 +803,6 @@ tidy_multinom_model <- function(model, ci.lvl, facets) {
 
 
 #' @importFrom stats coef qnorm pnorm
-#' @importFrom tibble tibble
 #' @importFrom rlang .data
 tidy_gam_model <- function(model, ci.lvl) {
 
@@ -779,13 +820,13 @@ tidy_gam_model <- function(model, ci.lvl) {
   se <- sqrt(diag(model$Ve))
   sm <- summary(model)
 
-  tibble::tibble(
+  data_frame(
     term = names(est),
     estimate = est,
     std.error = se,
     statistic = sm$p.t,
-    conf.low = .data$estimate - stats::qnorm(ci) * .data$std.error,
-    conf.high = .data$estimate + stats::qnorm(ci) * .data$std.error,
+    conf.low = est - stats::qnorm(ci) * se,
+    conf.high = est + stats::qnorm(ci) * se,
     p.value = sm$p.pv
   )
 }
@@ -811,13 +852,13 @@ tidy_zelig_model <- function(model, ci.lvl) {
   est <- Zelig::coef(model)
   se <- unlist(Zelig::get_se(model))
 
-  tibble::tibble(
+  data_frame(
     term = names(est),
     estimate = est,
     std.error = se,
-    statistic = .data$estimate / .data$std.error,
-    conf.low = .data$estimate - stats::qnorm(ci) * .data$std.error,
-    conf.high = .data$estimate + stats::qnorm(ci) * .data$std.error,
+    statistic = est / se,
+    conf.low = est - stats::qnorm(ci) * se,
+    conf.high = est + stats::qnorm(ci) * se,
     p.value = unname(unlist(Zelig::get_pvalue(model)))
   )
 }
